@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -621,7 +621,7 @@ sub BuildEmail {
             # running RT.
             local $SIG{__WARN__} = sub {};
 
-            my $inliner = CSS::Inliner->new;
+            my $inliner = CSS::Inliner->new( { encode_entities => 1, ignore_style_type_attr => 1 } );
             $inliner->read({ html => $content });
             $content = $inliner->inlinify();
         }
