@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -62,70 +62,116 @@ sub Dropbox {
     return $self->{Dropbox};
 }
 
-sub AccessToken {
+sub AppKey {
     my $self = shift;
-    return $self->{AccessToken};
+    return $self->{AppKey};
+}
+
+sub AppSecret {
+    my $self = shift;
+    return $self->{AppSecret};
+}
+
+sub RefreshToken {
+    my $self = shift;
+    return $self->{RefreshToken};
 }
 
 sub Init {
     my $self = shift;
 
-    if (not RT::StaticUtil::RequireModule("File::Dropbox")) {
-        RT->Logger->error("Required module File::Dropbox is not installed");
+    if ( not WebService::Dropbox->require ) {
+        RT->Logger->error("Required module WebService::Dropbox is not installed");
         return;
-    } elsif (not $self->AccessToken) {
-        RT->Logger->error("Required option 'AccessToken' not provided for Dropbox external storage. See the documentation for " . __PACKAGE__ . " for setting up this integration.");
+    }
+    WebService::Dropbox->import;
+    for my $item (qw/AppKey AppSecret RefreshToken/) {
+        next if $self->$item;
+        RT->Logger->error(
+                  "Required option '$item' not provided for Dropbox external storage. See the documentation for "
+                . __PACKAGE__
+                . " for setting up this integration." );
         return;
     }
 
-    my $dropbox = File::Dropbox->new(
-        oauth2       => 1,
-        access_token => $self->AccessToken,
-        root         => 'sandbox',
-        furlopts     => { timeout => 60 },
+    my $dropbox = WebService::Dropbox->new(
+        {
+            key    => $self->AppKey,
+            secret => $self->AppSecret,
+        }
     );
+
+    $dropbox->refresh_access_token( $self->RefreshToken );
     $self->Dropbox($dropbox);
 
     return $self;
 }
 
+# Dropbox requires the "/" prefix
+sub _FilePath {
+    my $self = shift;
+    my $sha = shift;
+    return "/$sha";
+}
+
+sub _PathExists {
+    my $self = shift;
+    my $path = shift;
+
+    # Get rid of expected warnings when path doesn't exist
+    local $SIG{__WARN__} = sub {};
+    return $self->Dropbox->get_metadata($path);
+}
+
 sub Get {
     my $self = shift;
     my ($sha) = @_;
+    my $path = $self->_FilePath($sha);
 
-    my $dropbox = $self->Dropbox;
-
-    open( $dropbox, "<", $sha)
-        or return (undef, "Failed to retrieve file from dropbox: $!");
-    my $content = do {local $/; <$dropbox>};
-    close $dropbox;
-
-    return ($content);
+    my $content;
+    open my $fh, '>', \$content;
+    $self->Dropbox->download($path, $fh);
+    close $fh;
+    if ( $content ) {
+        return ($content);
+    }
+    else {
+        return ( undef, "Read $sha from dropbox failed: " . $self->Dropbox->error );
+    }
 }
 
 sub Store {
     my $self = shift;
     my ($sha, $content, $attachment) = @_;
 
-    my $dropbox = $self->Dropbox;
+    my $path = $self->_FilePath($sha);
 
     # No-op if the path exists already.  This forces a metadata read.
-    return ($sha) if open( $dropbox, "<", $sha);
+    return ($sha) if $self->_PathExists($path);
 
-    open( $dropbox, ">", $sha )
-        or return (undef, "Open for write on dropbox failed: $!");
-    print $dropbox $content
-        or return (undef, "Write to dropbox failed: $!");
-    close $dropbox
-        or return (undef, "Flush to dropbox failed: $!");
-
-    return ($sha);
+    if ( $self->Dropbox->upload( $path, $content ) ) {
+        return ($sha);
+    }
+    else {
+        return ( undef, "Write $sha to dropbox failed: " . $self->Dropbox->error );
+    }
 }
 
 sub DownloadURLFor {
     return;
 }
 
+sub Delete {
+    my $self = shift;
+    my $sha  = shift;
+    my $path = $self->_FilePath($sha);
+
+    if ( $self->_PathExists($path) && !$self->Dropbox->delete($path) ) {
+        return ( undef, "Delete $sha from dropbox failed: " . $self->Dropbox->error );
+    }
+    return ($sha);
+}
+
 =head1 NAME
 
 RT::ExternalStorage::Dropbox - Store files in the Dropbox cloud
@@ -133,8 +179,10 @@ RT::ExternalStorage::Dropbox - Store files in the Dropbox cloud
 =head1 SYNOPSIS
 
     Set(%ExternalStorage,
-        Type => 'Dropbox',
-        AccessToken => '...',
+        Type         => 'Dropbox',
+        AccessKey    => '...',
+        AccessSecret => '...',
+        RefreshToken => '...',
     );
 
 =head1 DESCRIPTION
@@ -166,11 +214,11 @@ Click C<Create app> on L<https://www.dropbox.com/developers/apps>
 
 =item 3.
 
-Choose B<Dropbox API app> as the type of app.
+Choose B<Scoped access> as the API.
 
 =item 4.
 
-Choose B<App Folder> for the Type of Access; your application only needs access to files it creates.
+Choose B<App folder> as the type of access.
 
 =item 5.
 
@@ -178,20 +226,38 @@ Enter a descriptive name -- C<Request Tracker files> is fine.
 
 =item 6.
 
-Check the checkbox for B<Terms and Conditions> (if present) and then click C<Create App>.
+After creation, grant the following permissions on Permissions tab:
+
+    files.metadata.write
+    files.metadata.read
+    files.content.write
+    files.content.read
 
 =item 7.
 
-Under C<Generated access token>, click the C<Generate> button.
+On Settings tab, get C<App key>/C<App secret> and then access the following
+URL:
+
+    https://www.dropbox.com/oauth2/authorize?token_access_type=offline&response_type=code&client_id=<App key>
+
+Where <App key> is the one you got earlier.
+
+After a confirmation page, you will receive a code, use it along with C<App
+key> and C<App secret> in the following command and run it:
+
+    curl https://api.dropbox.com/oauth2/token -d code=<received code> -d grant_type=authorization_code -u <App key>:<App secret>
+
+The response shall contain C<refresh_token> value.
 
 =item 8.
 
-Copy the provided value into your F<RT_SiteConfig.pm> file as the
-C<AccessToken>:
+Copy the provided values into your F<RT_SiteConfig.pm>:
 
     Set(%ExternalStorage,
-        Type => 'Dropbox',
-        AccessToken => '...',   # Replace the value here, between the quotes
+        Type         => 'Dropbox',
+        AccessKey    => '...',
+        AccessSecret => '...',
+        RefreshToken => '...',       # Replace the value here, between the quotes
     );
 
 =back
