@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -493,6 +493,7 @@ sub Create {
         }
     }
 
+    $self->{ObjectCount}{$class}++;
     return $obj if $self->{Clone};
 
     # Users/Groups have id set in PreInflate, no need to set here
@@ -503,7 +504,6 @@ sub Create {
         $self->NextId( $class, $id + 1 );
     }
 
-    $self->{ObjectCount}{$class}++;
     $self->Resolve( $uid => $class, $id );
 
     # RT::User::PostInflate is just to call InitSystemObjects for RT_System user.
@@ -629,10 +629,13 @@ sub CloseStream {
 
     # Fill CGM
 
+    # $self here isn't an RT::Record
+    my $groups_table = RT::Group->can('QuotedTableName') ? RT::Group->QuotedTableName('Groups') : 'Groups';
+
     # Groups
-    $self->RunSQL(<<'EOF');
+    $self->RunSQL(<<"EOF");
 INSERT INTO CachedGroupMembers (GroupId, MemberId, Via, ImmediateParentId, Disabled)
-    SELECT Groups.id, Groups.id, 0, Groups.id, Principals.Disabled FROM Groups
+    SELECT Groups.id, Groups.id, NULL, Groups.id, Principals.Disabled FROM $groups_table
     LEFT JOIN Principals ON ( Groups.id = Principals.id )
     LEFT JOIN CachedGroupMembers ON (
         Groups.id = CachedGroupMembers.GroupId
@@ -645,7 +648,7 @@ EOF
     # GroupMembers
     $self->RunSQL(<<'EOF');
 INSERT INTO CachedGroupMembers (GroupId, MemberId, Via, ImmediateParentId, Disabled)
-    SELECT GroupMembers.GroupId, GroupMembers.MemberId, 0, GroupMembers.GroupId, Principals.Disabled FROM GroupMembers
+    SELECT GroupMembers.GroupId, GroupMembers.MemberId, NULL, GroupMembers.GroupId, Principals.Disabled FROM GroupMembers
     LEFT JOIN Principals ON ( GroupMembers.GroupId = Principals.id )
     LEFT JOIN CachedGroupMembers ON (
         GroupMembers.GroupId = CachedGroupMembers.GroupId
@@ -657,11 +660,11 @@ EOF
 
     # Fixup Via
     $self->RunSQL(<<'EOF');
-UPDATE CachedGroupMembers SET Via=id WHERE Via=0
+UPDATE CachedGroupMembers SET Via=id WHERE Via IS NULL
 EOF
 
     # Cascaded GroupMembers, use the same SQL in rt-validator
-    my $cascaded_cgm = <<'EOF';
+    my $cascaded_cgm = <<"EOF";
 INSERT INTO CachedGroupMembers (GroupId, MemberId, Via, ImmediateParentId, Disabled)
 SELECT cgm1.GroupId, gm2.MemberId, cgm1.id AS Via,
     cgm1.MemberId AS ImmediateParentId, cgm1.Disabled
@@ -673,7 +676,7 @@ FROM
         AND cgm3.MemberId          = gm2.MemberId
         AND cgm3.Via               = cgm1.id
         AND cgm3.ImmediateParentId = cgm1.MemberId )
-    LEFT JOIN Groups g ON (
+    LEFT JOIN $groups_table g ON (
         cgm1.GroupId = g.id
     )
 WHERE cgm1.GroupId != cgm1.MemberId
@@ -687,6 +690,8 @@ EOF
         last unless $rv > 0;
     }
 
+    $RT::Handle->Commit if !$self->{AutoCommit} && $RT::Handle->TransactionDepth;
+
     return if $self->{Clone};
 
     # Take global CFs which we made and make them un-global
@@ -747,7 +752,7 @@ sub BatchCreate {
         my @copy = @$items;
         @$items = ();
 
-        $RT::Handle->Commit unless $self->{AutoCommit};
+        $RT::Handle->Commit if !$self->{AutoCommit} && $RT::Handle->TransactionDepth;
         $RT::Handle->Disconnect;
 
         if ( $self->{_pm}->start ) {
@@ -837,11 +842,33 @@ sub _BatchCreate {
             $values_paren = $1;
         }
 
-        # DBs have placeholder limitations(64k for Pg), here we replace
-        # placeholders to support bigger batch sizes. The performance is similar.
-        my $batch_sql
-            = $RT::Handle->FillIn( $sql . ( ", $values_paren" x ( $count - 1 ) ), [ map @$_, @{ $query{$sql} } ] );
-        $self->RunSQL($batch_sql);
+        # Enforce a 256MB limit on query strings to get around database limitation.
+        my @query_bind_vals;
+        my ( $vals_size, $bind_vals_batch ) = ( 0, [] );
+        foreach my $bind_vals ( @{ $query{$sql} } ) {
+            my $length;
+            $length += length $_ for grep { defined $_ } @$bind_vals;
+
+            # check if over 250 MB to leave some extra room for $sql, commas, and quotes
+            if ( $vals_size + $length > 250 * 1024**2 ) {
+                push @query_bind_vals, $bind_vals_batch;
+                $vals_size       = 0;
+                $bind_vals_batch = [];
+            }
+            push @$bind_vals_batch, $bind_vals;
+            $vals_size += $length;
+        }
+        push @query_bind_vals, $bind_vals_batch if @$bind_vals_batch;
+
+        foreach my $bind_vals (@query_bind_vals) {
+            $count = @$bind_vals;
+
+            # DBs have placeholder limitations(64k for Pg), here we replace
+            # placeholders to support bigger batch sizes. The performance is similar.
+            my $batch_sql
+                = $RT::Handle->FillIn( $sql . ( ", $values_paren" x ( $count - 1 ) ), [ map @$_, @$bind_vals ] );
+            $self->RunSQL($batch_sql);
+        }
     }
 
     # Clone doesn't need to return anything
@@ -893,4 +920,6 @@ sub RunSQL {
     return $rv;
 }
 
+RT::Base->_ImportOverlays();
+
 1;
