@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -717,9 +717,6 @@ sub ShouldExcludeObject {
         return 1 if $record->{Domain} eq 'RT::System-Role'
                  || $record->{Domain} eq 'SystemInternal';
     }
-    elsif ($class eq 'RT::Queue') {
-        return 1 if $record->{Name} eq '___Approvals';
-    }
     elsif ($class eq 'RT::GroupMember') {
         return 1 if $record->{Group} eq 'Owner'
                  && $record->{GroupDomain} =~ /-Role$/
@@ -783,4 +780,6 @@ sub WriteFile {
     print { $self->{Filehandle} } $self->JSON->encode(\%output);
 }
 
+RT::Base->_ImportOverlays();
+
 1;
