@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -835,6 +835,14 @@ Below are some examples using the endpoints above.
     POST /users
         search for users using L</JSON searches> syntax
 
+    GET /users/privileged?query=<JSON>
+    POST /users/privileged
+        search for privileged users using L</JSON searches> syntax
+
+    GET /users/unprivileged?query=<JSON>
+    POST /users/unprivileged
+        search for unprivileged users using L</JSON searches> syntax
+
     POST /user
         create a user; provide JSON content
 
@@ -1471,4 +1479,6 @@ sub PSGIWrap {
     };
 }
 
+RT::Base->_ImportOverlays();
+
 1;
