@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -56,10 +56,27 @@ use namespace::autoclean;
 extends 'RT::REST2::Resource::Collection';
 with 'RT::REST2::Resource::Collection::QueryByJSON';
 
+has 'privileged' => (
+    is  => 'ro',
+    required => 0,
+);
+
 sub dispatch_rules {
     Path::Dispatcher::Rule::Regex->new(
-        regex => qr{^/users/?$},
-        block => sub { { collection_class => 'RT::Users' } },
+        regex => qr{^/users(?:/(privileged|unprivileged)?)?$},
+        block => sub {
+            my ($match, $req) = @_;
+            my $privileged = $match->pos(1);
+            if ( $privileged ) {
+                if ( lc $privileged eq 'privileged' ) {
+                    $privileged = 1;
+                }
+                else {
+                    $privileged = 0;
+                }
+            }
+            return { collection_class => 'RT::Users', privileged => $privileged }
+        },
     ),
 }
 
@@ -88,6 +105,22 @@ sub forbidden {
     return 1;
 }
 
+override 'limit_collection' => sub {
+    my $self = shift;
+    if ( defined $self->privileged ) {
+        if ( $self->privileged ) {
+            $self->collection->LimitToPrivileged;
+        }
+        else {
+            $self->collection->LimitToUnprivileged;
+        }
+    }
+
+    super();
+};
+
+RT::Base->_ImportOverlays();
+
 __PACKAGE__->meta->make_immutable;
 
 1;
