@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -149,7 +149,7 @@ sometimes when you have big mail loops you may hit it.
 Defaults to 1000.  To change this (for example, to 10000) add the
 following to your F<RT_SiteConfig.pm>:
 
-    Set( $DependenciesLimit, 10_000 );>
+    Set( $DependenciesLimit, 10_000 );
 
 
 =head2 $ShredderStoragePath
@@ -160,7 +160,7 @@ F</opt/rt5/var/data/RT-Shredder> (assuming an /opt/rt5 installation).
 To change this (for example, to /some/backup/path) add the following to
 your F<RT_SiteConfig.pm>:
 
-    Set( $ShredderStoragePath, "/some/backup/path" );>
+    Set( $ShredderStoragePath, "/some/backup/path" );
 
 Be sure to specify an absolute path.
 
@@ -351,6 +351,8 @@ sub CastObjectsToRecords
         while( my $tmp = $targets->Next ) { push @res, $tmp };
     } elsif ( UNIVERSAL::isa( $targets, 'RT::Record' ) ) {
         push @res, $targets;
+    } elsif ( UNIVERSAL::isa( $targets, 'RT::Shredder::RawRecord' ) ) {
+        push @res, $targets;
     } elsif ( UNIVERSAL::isa( $targets, 'ARRAY' ) ) {
         foreach( @$targets ) {
             push @res, $self->CastObjectsToRecords( Objects => $_ );
@@ -439,7 +441,7 @@ sub PutObject
     my %args = ( Object => undef, @_ );
 
     my $obj = $args{'Object'};
-    unless( UNIVERSAL::isa( $obj, 'RT::Record' ) ) {
+    if( !UNIVERSAL::isa( $obj, 'RT::Record' ) && !UNIVERSAL::isa( $obj, 'RT::Shredder::RawRecord' ) ) {
         RT::Shredder::Exception->throw( "Unsupported type '". (ref $obj || $obj || '(undef)')."'" );
     }
 
@@ -822,6 +824,8 @@ sub RollbackDumpTo {
 }
 }
 
+RT::Base->_ImportOverlays();
+
 1;
 __END__
 
