@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2017 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -58,7 +58,7 @@ RT::Shredder::Constants -  RT::Shredder constants that is used to mark state of
 =head1 DESCRIPTION
 
 This module contains two group of bit constants.
-First group is group of flags which are used to clarify dependecies between objects, and
+First group is group of flags which are used to clarify dependencies between objects, and
 second group is states of RT objects in Shredder cache.
 
 =head1 FLAGS
@@ -99,9 +99,9 @@ loaded and placed into cache.
 
 =head2 WIPED
 
-Objects with this state are not exist any more in DB, but perl
-object is still in memory. This state is used to be shure that
-delete query is called once.
+Objects with this state no longer exist in the DB, but the Perl
+object is still in memory. This state is used to be sure that
+the delete query is called once.
 
 =cut
 
@@ -111,4 +111,6 @@ use constant {
     WIPED     => 0x020,
 };
 
+RT::Base->_ImportOverlays();
+
 1;
